summaryrefslogtreecommitdiffstats
path: root/libkdepim/kregexp3.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kregexp3.h')
-rw-r--r--libkdepim/kregexp3.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/libkdepim/kregexp3.h b/libkdepim/kregexp3.h
index 40c7681d..c9b53c5f 100644
--- a/libkdepim/kregexp3.h
+++ b/libkdepim/kregexp3.h
@@ -36,21 +36,21 @@
#include <kdepimmacros.h>
/** @short A TQRegExp (Qt3.x) with a replace() method.
This class is simply there to provide a namespace for some nice
enhancements of the mighty TQRegExp (Qt3 version) regular
- expression engine, namely the method replace(), which can be
- used to do search-and-replace like one is used to from perl or sed.
+ expression engine, namely the method tqreplace(), which can be
+ used to do search-and-tqreplace like one is used to from perl or sed.
- It "simply" adds the ability to define a replacement string which
- contains references to the captured substrings. The following
+ It "simply" adds the ability to define a tqreplacement string which
+ tqcontains references to the captured substrings. The following
constructs are understood, which can be freely mixed in the
- replacement string:
+ tqreplacement string:
@section Sed syntax
- Back references in the replacement string are made using \n
+ Back references in the tqreplacement string are made using \n
(backslash-digit), where @p n is a single digit. With this mode of
operation, only the first nine captured substrings can be
referenced.
@@ -60,7 +60,7 @@
@section Perl syntax
- Back references in the replacement string are made using $n
+ Back references in the tqreplacement string are made using $n
(dollarsign-digit), where @p n is a single digit. With this mode
of operation, only the first nine captured substrings can be
referenced.
@@ -91,21 +91,21 @@ public:
: TQRegExp( (TQRegExp)rx ) {}
/** Replaces each matching subpattern in @p str with
- @p replacementStr, inserting captured substrings for
+ @p tqreplacementStr, inserting captured substrings for
\\n, $n and ${nn} as described in the class documentation.
@param str The source string.
- @param replacementStr The string which replaces matched
+ @param tqreplacementStr The string which tqreplaces matched
substrings of @p str.
@param start Start position for the search.
If @p start is negative, starts @p -(start) positions
from the end of @p str.
- @param global If @p TRUE, requests to replace all occurrences
- of the regexp with @p replacementStr; if @p FALSE,
- only the first occurrence will be replaced.
+ @param global If @p TRUE, requests to tqreplace all occurrences
+ of the regexp with @p tqreplacementStr; if @p FALSE,
+ only the first occurrence will be tqreplaced.
Equivalent to the /g switch to perl's s/// operator.
@return The modified string.
*/
- TQString replace( const TQString & str,
- const TQString & replacementStr,
+ TQString tqreplace( const TQString & str,
+ const TQString & tqreplacementStr,
int start=0, bool global=TRUE );
};
@@ -36,21 +36,21 @@
#include <kdepimmacros.h>
-/** @short A TQRegExp (Qt3.x) with a replace() method.
+/** @short A TQRegExp (Qt3.x) with a tqreplace() method.
This class is simply there to provide a namespace for some nice
enhancements of the mighty TQRegExp (Qt3 version) regular